@@ -1,6 +1,6 @@
 import numpy as np
 
-from ._classes import (
+from ._gradient_descent import (
   GD
 )
 
